# Changelog:
# 2020-04-26
# added "positioned ~ 63 ~" to /tag @e[tag=wave] to make sure shells spawn whatever is the y position of the wave spawners
# added commands to kill each shell after 1 minute
# added second step of randomization
# 2020-04-27 - added command to change shells' rotation
# 2020-04-28 - changed CustomModelData of shells
# 2020-08-03 - added option to use the "multiple shores" configuration by giving the tag "stop_circling" to island_centre
# 2020-08-07 - added commands to forceload only the chunk where island_centre is currently located (moved island_centre's tp to a beach_point before the wave_spawner stands' tps)
# 2020-08-19 - changed wave spawners' elevation to be sea level +2 so they don't produce bubble particles (shown when an entity is inside water) and added "optional changes" section
# 2020-08-20 - made each wave grow sooner (and added mention to it in the "optional changes" section)
# 2020-08-23 - changed a commands for multiplayer and added "multiplayer compatibility" section and video link


# 2020-08-03:
# WHAT YOU NEED TO DO FOR THE SETUP:
# 1 - Change the sea level in the commands
# 2 - Decide if you want to use the "circular island" (default) or the "multiple shores" configuration
# 3 - Change the coordinates of the tp commands for the wave_spawner stands and the spreadplayers command
# If, during the setup, the datapack is already active, some waves might get stuck on island_centre and don't despawn; use this command to remove them:
# /kill @e[tag=wave]
# Read carefully all the following lines for more information

# 2020-08-03
# This datapack was firstly designed to work on circular islands: it's the easiest option, as it requires less commands and entities ("circular island" configuration)
# Still, you can decide to use this datapack on different type of beaches ("multiple shores" configuration)
# The concept is that instead of a single point where the waves are directed (the island centre), you can set multiple points, each one corresponding to a portion of your beach
# Best way to do it is to divide the beach in a number of similarly big straight shores, but the only limit is how much you're willing to be precise
# For each shore, you will need to manually spawn a marker armor stand, using this command:
# /summon armor_stand ~ ~ ~ {Marker:true,NoGravity:true,Invisible:true,Tags:["beach_point"],Rotation:[0.0f,0.0f]}
# For the coordinates, choose the center of each shore and makes sure they are all the same distance from the sea
# The y coordinate of each beach point should be sea level +2 to stop bubbles particles from being produced by wave spawners
# For Rotation, you have to make them face away from the water: for example, if the beach goes from east to west and the sea is on south, the rotation needs to be 180° (north)
# Summoned all the beach_point stands, activate this commands in chat:
# /tag @e[tag=island_centre] add stop_circling
# Keep in mind the commands you have to change in this function: change their coordinates to reflect the size of the shores, rather than the size of the island
# Remember also that waves need to reach a shore to despawn: make sure the wave_spawner stands have a shore in front of them at all times

# 2020-08-03
# The "63" you can see in many commands is the sea level +1 (62+1) of the world; if your world has a different sea level, change this number in all the commands

# 2020-08-07
# ABOUT CHUNK LOADING: as it is the case with any contraption that uses entities, this datpack will work only if the armor stand with the tag "island_centre" is in a loaded chunk
# The best way to ensure that is to have the island centre in one of the spawn chunks, which are constantly loaded
# Still, that could be not possible or, if you use the "multiple shores" configuration, the beaches could be too big or numerous to be all inside spawn
# For this reason, you can choose to have these commands active:
forceload remove all
execute at @e[tag=island_centre] run forceload add ~ ~ ~ ~
# With the second command, the chunk where island_centre is located will be loaded every tick
# Immediately before that, the first command removes all the previously loaded chunks to ensure that only one chunk is loaded every tick
# BEWARE: while these commands will ensure the datapack always works, they may interfere with other forceload commands or result in making the game too laggy
# These commands are not needed if you ensure that island_centre is always inside a spawn chunk, so you can freely remove them if that's the case
# YOU MUST be careful with forceload, it can potentially lag the game a lot, so be sure to understand which chunks need to be loaded

# 2020-08-19
# OPTIONAL CHANGES:
# 1 - change how often waves are spawned (default 150 ticks)
# 2 - change the number of wave spawners (default 5)
# 3 - change the size of each wave (default 9 blocks for a fully formed wave) and how it gets bigger
# 4 - change how shells are generated and removed
# Keep in mind performance when modifying commands, as they can be taxing on less powerful PCs

# 2020-08-22
# MULTIPLAYER COMPATIBILITY:
# The datapack was designed for singleplayer: if you use this datapack in multiplayer, the wave spawners will follow the player closest to the island centre
# This doesn't break the datapack, but waves will only appear relatively to one player at a time
# If you use this datapack in multiplayer, the "multiple shores" configuration will work a little better
# Alternatively, you can stop the wave spawners from following the player, increase their number and manually position them on the water bodies of your choice



# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Waves randomizer - every 117 ticks, a wave is spawned on one of the stands

# If you decide to use the "multiple shores" configuration, doing so will deactivate some commands and activate the ones below
# This command simply teleports island_centre to the beach_point nearest to the player
# 2020-08-23 - Changed the command to target the player closest to the island centre
execute at @e[tag=island_centre,tag=stop_circling] at @p run tp @e[tag=island_centre,tag=stop_circling] @e[tag=beach_point,limit=1,sort=nearest]
# This command flips the rotation of island_centre, after it gets the rotation of the nearest beach_point, so that the wave_spawner stands are teleported correctly
execute as @e[tag=island_centre,tag=stop_circling] at @s run tp @s ~ ~ ~ ~180 ~


# The stand at the center of the island is rotated to always face the player
# This commands doesn't work if you decide to use the "multiple shores" configuration
execute as @e[tag=island_centre,tag=!stop_circling] at @s facing entity @p feet run tp @s ~ ~ ~ ~ 0

# The stands on which the waves are spawned circle around the island following the player
execute as @e[tag=wave_spawner,tag=0] at @e[tag=island_centre] run tp @s ^ ^ ^87
execute as @e[tag=wave_spawner,tag=1] at @e[tag=island_centre] run tp @s ^25 ^ ^85
execute as @e[tag=wave_spawner,tag=2] at @e[tag=island_centre] run tp @s ^50 ^ ^80
execute as @e[tag=wave_spawner,tag=3] at @e[tag=island_centre] run tp @s ^-25 ^ ^85
execute as @e[tag=wave_spawner,tag=4] at @e[tag=island_centre] run tp @s ^-50 ^ ^80
# You are not limited to these 5 wave_spawner stands: add one of these teleport commands for each one you decide to add
# Change the coordinates to reflect the size of your island (or of the multiple shores): the wave_spawner stands needs to hover over water, at some distance from the beach

# Scoreboard controller
scoreboard players add waves wave 1
execute if score waves wave matches 117.. run scoreboard players set waves wave 0
# 2020-11-30 - added .. to 117, don't know why it wasn't like that before...
# This command will spawn a wave on a random stand every 117 ticks
execute as @e[tag=wave_spawner,limit=1,sort=random] at @s if score waves wave matches 1 run summon area_effect_cloud ~ 63 ~ {NoGravity:true,Tags:["wave"],Duration:999999}
# 2020-11-30 - changed wave spawn timer from 150 to 117 ticks to match the waves sound-effects in the island's music track (one every 5.85 seconds)

# Second step of randomization: island_centre moves randomly, moving in this way also the wave spawners
# Change the coordinates of spreadplayers to be the island's center (you can also customize the range), but remember that it works only if there's ground around it
# These commands don't work if you decide to use the "multiple shores" configuration
execute if score waves wave matches 0 run spreadplayers 0 0 0 6 false @e[tag=island_centre,tag=!stop_circling]
# 2020-08-19 - This command teleports island_centre, and so also the wave spawners, to the sea level +2: it's +2 instead of +1 so that the wave spawners can't produce bubble particles
execute if score waves wave matches 0 run execute as @e[tag=island_centre,tag=!stop_circling] at @s run tp @s ~ 64 ~


# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Wave controller - creates the wave

# Each wave is oriented to face the centre of the island
# This commands doesn't work if you decide to use the "multiple shores" configuration
execute as @e[tag=wave] at @s facing entity @e[tag=island_centre,tag=!stop_circling] feet run tp @s ~ ~ ~ ~ 0
# Each wave is directed towards the centre of the island (unless you use the command after this one)
execute as @e[tag=wave,tag=!wave_back] at @s run tp @s ^ ^ ^0.2

# If you decide to use the "multiple shores" configuration, this command will direct the waves in the same direction of the nearest beach_point
# Remember to correctly orientate the beach_point armor stands for this to work correctly
execute as @e[tag=wave,tag=!wave_back] at @s run data modify entity @s Rotation set from entity @e[tag=beach_point,limit=1,sort=nearest] Rotation

# 20 ticks after a wave has reached the beach, it turns back for 15 ticks and then killed by using the timer of the area effect cloud used as a marker for the wave
# The timer is kept at 1000 as long as the marker is on top of water
execute as @e[tag=wave,tag=!wave_back] at @s if block ~ ~-1 ~ water run data merge entity @s {Age:1000}
# Once the marker is no longer on top of water, the timer is free to increase
execute as @e[tag=wave,nbt={Age:1020}] run tag @s add wave_back
execute as @e[tag=wave,tag=wave_back] at @s run tp @s ^ ^ ^-0.2
execute as @e[tag=wave,nbt={Age:1035}] run kill @s


# Life cycle of the wave, controlled by the distance from the beach ("unless block ^ ^-1 ^X water")

# Fully formed wave
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^-3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=1] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^4 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=4] replace air
execute as @e[tag=wave] at @s if block ^ ^-1 ^-4 water unless block ^ ^-1 ^15 water positioned ^-4 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=4] replace air

# Once the wave reaches the beach, the wave starts to disperd
# Every water and air block is replaced by low water to simulate the wave being absorbed by the beach
execute as @e[tag=wave,tag=wave_back] at @s positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^4 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-4 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=7] replace water

execute as @e[tag=wave,tag=wave_back] at @s positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^3 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-3 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^4 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-4 ^ ^ run fill ^ ^ ^ ^ ^ ^-1 water[level=7] replace air

# Any water block now behind the wave is set to air to simulate the retreat of the wave
execute as @e[tag=wave,tag=wave_back] at @s positioned ^ ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^1 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-1 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^2 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-2 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^3 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-3 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^4 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water
execute as @e[tag=wave,tag=wave_back] at @s positioned ^-4 ^ ^ run fill ^ ^ ^1 ^ ^ ^1 air replace water

# At the beginning, the wave is smaller
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=6] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=6] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=6] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=6] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=6] replace air

execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^40 water positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=5] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^40 water positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=5] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^40 water positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=5] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^40 water positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=5] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^40 water positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=5] replace air

execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^ ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^-1 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^-2 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air
execute as @e[tag=wave] at @s if block ~ ~-1 ~4 water unless block ^ ^-1 ^25 water positioned ^-3 ^ ^ run fill ^ ^ ^ ^ ^ ^ water[level=3] replace air


# The wave's sound increases when closer to the beach
execute as @e[tag=wave,tag=!wave_back] at @s if block ~ ~-1 ~ water unless block ^ ^-1 ^20 water run playsound minecraft:weather.rain.above master @a ~ ~ ~ 0.01
execute as @e[tag=wave,tag=!wave_back] at @s if block ~ ~-1 ~ water unless block ^ ^-1 ^15 water run playsound minecraft:weather.rain.above master @a ~ ~ ~ 0.025

# The closer the wave is to the beach and more particles appears on the wave crest
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^9 water positioned ^ ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 7 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^9 water positioned ^1 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 6 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^9 water positioned ^-1 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 6 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^7 water positioned ^2 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 6 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^7 water positioned ^-2 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 6 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^5 water positioned ^3 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 5 force
execute as @e[tag=wave,tag=!wave_back] at @s unless block ^ ^-1 ^5 water positioned ^-3 ^ ^ run particle minecraft:item cobweb ^ ^0.4 ^0.2 0.3 0.1 0.3 0.01 5 force

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Shell spawner (needs resource pack)

# Each wave has a chance to spawn a shell (the probability depends from "distance=")
execute at @e[tag=wave_spawner,limit=1,sort=random] positioned ~ 63 ~ run execute as @e[tag=wave,distance=..0.3] run tag @s add wave_shell1
execute at @e[tag=wave_spawner,limit=1,sort=random] positioned ~ 63 ~ run execute as @e[tag=wave,distance=..0.3] run tag @s add wave_shell2
# If the wave has one of these tags, it will spawn one of two type of shells; if it has both, it will spawn a third type
execute as @e[tag=wave_shell1,tag=!wave_shell2,nbt={Age:1018}] at @s unless entity @e[tag=shell,distance=..2] if block ~ ~ ~ water run summon armor_stand ~ ~-1.82 ~ {Invisible:true,NoGravity:true,Marker:true,Fire:100s,ArmorItems:[{},{},{},{id:nautilus_shell,Count:1b,tag:{CustomModelData:1}}],Tags:["shell","1"]}
execute as @e[tag=wave_shell2,tag=!wave_shell1,nbt={Age:1018}] at @s unless entity @e[tag=shell,distance=..2] if block ~ ~ ~ water run summon armor_stand ~ ~-1.82 ~ {Invisible:true,NoGravity:true,Marker:true,Fire:100s,ArmorItems:[{},{},{},{id:nautilus_shell,Count:1b,tag:{CustomModelData:2}}],Tags:["shell","2"]}
execute as @e[tag=wave_shell1,tag=wave_shell2,nbt={Age:1018}] at @s unless entity @e[tag=shell,distance=..2] if block ~ ~ ~ water run summon armor_stand ~ ~-1.82 ~ {Invisible:true,NoGravity:true,Marker:true,Fire:100s,ArmorItems:[{},{},{},{id:nautilus_shell,Count:1b,tag:{CustomModelData:3}}],Tags:["shell","3"]}

# This command will rotate the shells towards the wave that brought them on the shore
execute as @e[tag=shell,scores={wave=1}] at @s run tp @s ~ ~ ~ facing entity @e[tag=wave,limit=1,sort=nearest]

# This command makes sure the shells are kept bright
# 2020-08-26 - Because of the bug MC-181134, this command has been changed to work only for one tick
execute as @e[tag=shell,nbt={Fire:0s}] run data merge entity @s {Fire:100s}


# Each wave also a chance to wash away any shell it touches
execute at @e[tag=wave_spawner,limit=1,sort=random] positioned ~ 63 ~ run execute as @e[tag=wave,distance=..0.35] run tag @s add wave_wash
execute as @e[tag=wave_wash,nbt={Age:1018}] at @s run kill @e[tag=shell,distance=..4]

# These commands make each shell automatically vanish after 1 minute by sinking in the sand
scoreboard players add @e[tag=shell] wave 1
execute as @e[tag=shell,scores={wave=1200..}] at @s run tp @s ~ ~-0.001 ~
kill @e[tag=shell,scores={wave=1350..}]


# Video about this datapack: https://youtu.be/CD_URVP84LI
# This work is licensed under a Creative Commons Attribution-NonCommercial-NoDerivatives 4.0 International License.
# You can monetize videos about this datapack; for any other exception, like modifying the datapack, you must first contact the creator.
# This data pack can be used freely; if you do intend to use this data pack for a custom map, you have to credit the creator, PmkExpert, in a visible way.
# Contact on Reddit for any question: https://www.reddit.com/user/Pmk23
# Visit Planet Minecraft for the latest updates: https://www.planetminecraft.com/member/pmk/
# Social Medias: https://twitter.com/PmkExpert https://www.youtube.com/user/Pmkexpert